# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2026.2.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from uuid import UUID
from authentik_client.models.device_access_group import DeviceAccessGroup
from authentik_client.models.device_connection import DeviceConnection
from authentik_client.models.device_fact_snapshot import DeviceFactSnapshot
from typing import Optional, Set
from typing_extensions import Self

class EndpointDeviceDetails(BaseModel):
    """
    EndpointDeviceDetails
    """ # noqa: E501
    device_uuid: Optional[UUID] = None
    pbm_uuid: UUID
    name: StrictStr
    access_group: Optional[UUID] = None
    access_group_obj: Optional[DeviceAccessGroup] = None
    expiring: Optional[StrictBool] = None
    expires: Optional[datetime] = None
    facts: DeviceFactSnapshot
    attributes: Optional[Dict[str, Any]] = None
    connections_obj: List[DeviceConnection]
    policies: List[UUID]
    connections: List[UUID]
    __properties: ClassVar[List[str]] = ["device_uuid", "pbm_uuid", "name", "access_group", "access_group_obj", "expiring", "expires", "facts", "attributes", "connections_obj", "policies", "connections"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of EndpointDeviceDetails from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "pbm_uuid",
            "facts",
            "policies",
            "connections",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of access_group_obj
        if self.access_group_obj:
            _dict['access_group_obj'] = self.access_group_obj.to_dict()
        # override the default output from pydantic by calling `to_dict()` of facts
        if self.facts:
            _dict['facts'] = self.facts.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in connections_obj (list)
        _items = []
        if self.connections_obj:
            for _item_connections_obj in self.connections_obj:
                if _item_connections_obj:
                    _items.append(_item_connections_obj.to_dict())
            _dict['connections_obj'] = _items
        # set to None if access_group (nullable) is None
        # and model_fields_set contains the field
        if self.access_group is None and "access_group" in self.model_fields_set:
            _dict['access_group'] = None

        # set to None if expires (nullable) is None
        # and model_fields_set contains the field
        if self.expires is None and "expires" in self.model_fields_set:
            _dict['expires'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of EndpointDeviceDetails from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "device_uuid": obj.get("device_uuid"),
            "pbm_uuid": obj.get("pbm_uuid"),
            "name": obj.get("name"),
            "access_group": obj.get("access_group"),
            "access_group_obj": DeviceAccessGroup.from_dict(obj["access_group_obj"]) if obj.get("access_group_obj") is not None else None,
            "expiring": obj.get("expiring"),
            "expires": obj.get("expires"),
            "facts": DeviceFactSnapshot.from_dict(obj["facts"]) if obj.get("facts") is not None else None,
            "attributes": obj.get("attributes"),
            "connections_obj": [DeviceConnection.from_dict(_item) for _item in obj["connections_obj"]] if obj.get("connections_obj") is not None else None,
            "policies": obj.get("policies"),
            "connections": obj.get("connections")
        })
        return _obj


