# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2026.2.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.endpoints_api import EndpointsApi


class TestEndpointsApi(unittest.TestCase):
    """EndpointsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = EndpointsApi()

    def tearDown(self) -> None:
        pass

    def test_endpoints_agents_connectors_agent_config_retrieve(self) -> None:
        """Test case for endpoints_agents_connectors_agent_config_retrieve

        """
        pass

    def test_endpoints_agents_connectors_auth_fed_create(self) -> None:
        """Test case for endpoints_agents_connectors_auth_fed_create

        """
        pass

    def test_endpoints_agents_connectors_auth_ia_create(self) -> None:
        """Test case for endpoints_agents_connectors_auth_ia_create

        """
        pass

    def test_endpoints_agents_connectors_check_in_create(self) -> None:
        """Test case for endpoints_agents_connectors_check_in_create

        """
        pass

    def test_endpoints_agents_connectors_create(self) -> None:
        """Test case for endpoints_agents_connectors_create

        """
        pass

    def test_endpoints_agents_connectors_destroy(self) -> None:
        """Test case for endpoints_agents_connectors_destroy

        """
        pass

    def test_endpoints_agents_connectors_enroll_create(self) -> None:
        """Test case for endpoints_agents_connectors_enroll_create

        """
        pass

    def test_endpoints_agents_connectors_list(self) -> None:
        """Test case for endpoints_agents_connectors_list

        """
        pass

    def test_endpoints_agents_connectors_mdm_config_create(self) -> None:
        """Test case for endpoints_agents_connectors_mdm_config_create

        """
        pass

    def test_endpoints_agents_connectors_partial_update(self) -> None:
        """Test case for endpoints_agents_connectors_partial_update

        """
        pass

    def test_endpoints_agents_connectors_retrieve(self) -> None:
        """Test case for endpoints_agents_connectors_retrieve

        """
        pass

    def test_endpoints_agents_connectors_update(self) -> None:
        """Test case for endpoints_agents_connectors_update

        """
        pass

    def test_endpoints_agents_connectors_used_by_list(self) -> None:
        """Test case for endpoints_agents_connectors_used_by_list

        """
        pass

    def test_endpoints_agents_enrollment_tokens_create(self) -> None:
        """Test case for endpoints_agents_enrollment_tokens_create

        """
        pass

    def test_endpoints_agents_enrollment_tokens_destroy(self) -> None:
        """Test case for endpoints_agents_enrollment_tokens_destroy

        """
        pass

    def test_endpoints_agents_enrollment_tokens_list(self) -> None:
        """Test case for endpoints_agents_enrollment_tokens_list

        """
        pass

    def test_endpoints_agents_enrollment_tokens_partial_update(self) -> None:
        """Test case for endpoints_agents_enrollment_tokens_partial_update

        """
        pass

    def test_endpoints_agents_enrollment_tokens_retrieve(self) -> None:
        """Test case for endpoints_agents_enrollment_tokens_retrieve

        """
        pass

    def test_endpoints_agents_enrollment_tokens_update(self) -> None:
        """Test case for endpoints_agents_enrollment_tokens_update

        """
        pass

    def test_endpoints_agents_enrollment_tokens_used_by_list(self) -> None:
        """Test case for endpoints_agents_enrollment_tokens_used_by_list

        """
        pass

    def test_endpoints_agents_enrollment_tokens_view_key_retrieve(self) -> None:
        """Test case for endpoints_agents_enrollment_tokens_view_key_retrieve

        """
        pass

    def test_endpoints_agents_psso_register_device_create(self) -> None:
        """Test case for endpoints_agents_psso_register_device_create

        """
        pass

    def test_endpoints_agents_psso_register_user_create(self) -> None:
        """Test case for endpoints_agents_psso_register_user_create

        """
        pass

    def test_endpoints_connectors_destroy(self) -> None:
        """Test case for endpoints_connectors_destroy

        """
        pass

    def test_endpoints_connectors_list(self) -> None:
        """Test case for endpoints_connectors_list

        """
        pass

    def test_endpoints_connectors_retrieve(self) -> None:
        """Test case for endpoints_connectors_retrieve

        """
        pass

    def test_endpoints_connectors_types_list(self) -> None:
        """Test case for endpoints_connectors_types_list

        """
        pass

    def test_endpoints_connectors_used_by_list(self) -> None:
        """Test case for endpoints_connectors_used_by_list

        """
        pass

    def test_endpoints_device_access_groups_create(self) -> None:
        """Test case for endpoints_device_access_groups_create

        """
        pass

    def test_endpoints_device_access_groups_destroy(self) -> None:
        """Test case for endpoints_device_access_groups_destroy

        """
        pass

    def test_endpoints_device_access_groups_list(self) -> None:
        """Test case for endpoints_device_access_groups_list

        """
        pass

    def test_endpoints_device_access_groups_partial_update(self) -> None:
        """Test case for endpoints_device_access_groups_partial_update

        """
        pass

    def test_endpoints_device_access_groups_retrieve(self) -> None:
        """Test case for endpoints_device_access_groups_retrieve

        """
        pass

    def test_endpoints_device_access_groups_update(self) -> None:
        """Test case for endpoints_device_access_groups_update

        """
        pass

    def test_endpoints_device_access_groups_used_by_list(self) -> None:
        """Test case for endpoints_device_access_groups_used_by_list

        """
        pass

    def test_endpoints_device_bindings_create(self) -> None:
        """Test case for endpoints_device_bindings_create

        """
        pass

    def test_endpoints_device_bindings_destroy(self) -> None:
        """Test case for endpoints_device_bindings_destroy

        """
        pass

    def test_endpoints_device_bindings_list(self) -> None:
        """Test case for endpoints_device_bindings_list

        """
        pass

    def test_endpoints_device_bindings_partial_update(self) -> None:
        """Test case for endpoints_device_bindings_partial_update

        """
        pass

    def test_endpoints_device_bindings_retrieve(self) -> None:
        """Test case for endpoints_device_bindings_retrieve

        """
        pass

    def test_endpoints_device_bindings_update(self) -> None:
        """Test case for endpoints_device_bindings_update

        """
        pass

    def test_endpoints_device_bindings_used_by_list(self) -> None:
        """Test case for endpoints_device_bindings_used_by_list

        """
        pass

    def test_endpoints_devices_destroy(self) -> None:
        """Test case for endpoints_devices_destroy

        """
        pass

    def test_endpoints_devices_list(self) -> None:
        """Test case for endpoints_devices_list

        """
        pass

    def test_endpoints_devices_partial_update(self) -> None:
        """Test case for endpoints_devices_partial_update

        """
        pass

    def test_endpoints_devices_retrieve(self) -> None:
        """Test case for endpoints_devices_retrieve

        """
        pass

    def test_endpoints_devices_summary_retrieve(self) -> None:
        """Test case for endpoints_devices_summary_retrieve

        """
        pass

    def test_endpoints_devices_update(self) -> None:
        """Test case for endpoints_devices_update

        """
        pass

    def test_endpoints_devices_used_by_list(self) -> None:
        """Test case for endpoints_devices_used_by_list

        """
        pass

    def test_endpoints_fleet_connectors_create(self) -> None:
        """Test case for endpoints_fleet_connectors_create

        """
        pass

    def test_endpoints_fleet_connectors_destroy(self) -> None:
        """Test case for endpoints_fleet_connectors_destroy

        """
        pass

    def test_endpoints_fleet_connectors_list(self) -> None:
        """Test case for endpoints_fleet_connectors_list

        """
        pass

    def test_endpoints_fleet_connectors_partial_update(self) -> None:
        """Test case for endpoints_fleet_connectors_partial_update

        """
        pass

    def test_endpoints_fleet_connectors_retrieve(self) -> None:
        """Test case for endpoints_fleet_connectors_retrieve

        """
        pass

    def test_endpoints_fleet_connectors_update(self) -> None:
        """Test case for endpoints_fleet_connectors_update

        """
        pass

    def test_endpoints_fleet_connectors_used_by_list(self) -> None:
        """Test case for endpoints_fleet_connectors_used_by_list

        """
        pass


if __name__ == '__main__':
    unittest.main()
