# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2026.2.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.patched_application_request import PatchedApplicationRequest

class TestPatchedApplicationRequest(unittest.TestCase):
    """PatchedApplicationRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PatchedApplicationRequest:
        """Test PatchedApplicationRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PatchedApplicationRequest`
        """
        model = PatchedApplicationRequest()
        if include_optional:
            return PatchedApplicationRequest(
                name = '0',
                slug = 'z0',
                provider = 56,
                backchannel_providers = [
                    56
                    ],
                open_in_new_tab = True,
                meta_launch_url = '',
                meta_icon = '',
                meta_description = '',
                meta_publisher = '',
                policy_engine_mode = 'all',
                group = ''
            )
        else:
            return PatchedApplicationRequest(
        )
        """

    def testPatchedApplicationRequest(self):
        """Test PatchedApplicationRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
