# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2026.2.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.paginated_authenticator_email_stage_list import PaginatedAuthenticatorEmailStageList

class TestPaginatedAuthenticatorEmailStageList(unittest.TestCase):
    """PaginatedAuthenticatorEmailStageList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedAuthenticatorEmailStageList:
        """Test PaginatedAuthenticatorEmailStageList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedAuthenticatorEmailStageList`
        """
        model = PaginatedAuthenticatorEmailStageList()
        if include_optional:
            return PaginatedAuthenticatorEmailStageList(
                pagination = authentik_client.models.pagination.Pagination(
                    next = 1.337, 
                    previous = 1.337, 
                    count = 1.337, 
                    current = 1.337, 
                    total_pages = 1.337, 
                    start_index = 1.337, 
                    end_index = 1.337, ),
                results = [
                    authentik_client.models.authenticator_email_stage.AuthenticatorEmailStage(
                        pk = '', 
                        name = '', 
                        component = '', 
                        verbose_name = '', 
                        verbose_name_plural = '', 
                        meta_model_name = '', 
                        flow_set = [
                            authentik_client.models.flow_set.FlowSet(
                                pk = '', 
                                policybindingmodel_ptr_id = '', 
                                name = '', 
                                slug = 'z', 
                                title = '', 
                                designation = null, 
                                background_url = '', 
                                policy_engine_mode = 'all', 
                                compatibility_mode = True, 
                                export_url = '', 
                                layout = 'stacked', 
                                denied_action = null, )
                            ], 
                        configure_flow = '', 
                        friendly_name = '', 
                        use_global_settings = True, 
                        host = '', 
                        port = -2147483648, 
                        username = '', 
                        password = '', 
                        use_tls = True, 
                        use_ssl = True, 
                        timeout = -2147483648, 
                        from_address = '', 
                        subject = '', 
                        token_expiry = '', 
                        template = '', )
                    ],
                autocomplete = {
                    'key' : null
                    }
            )
        else:
            return PaginatedAuthenticatorEmailStageList(
                pagination = authentik_client.models.pagination.Pagination(
                    next = 1.337, 
                    previous = 1.337, 
                    count = 1.337, 
                    current = 1.337, 
                    total_pages = 1.337, 
                    start_index = 1.337, 
                    end_index = 1.337, ),
                results = [
                    authentik_client.models.authenticator_email_stage.AuthenticatorEmailStage(
                        pk = '', 
                        name = '', 
                        component = '', 
                        verbose_name = '', 
                        verbose_name_plural = '', 
                        meta_model_name = '', 
                        flow_set = [
                            authentik_client.models.flow_set.FlowSet(
                                pk = '', 
                                policybindingmodel_ptr_id = '', 
                                name = '', 
                                slug = 'z', 
                                title = '', 
                                designation = null, 
                                background_url = '', 
                                policy_engine_mode = 'all', 
                                compatibility_mode = True, 
                                export_url = '', 
                                layout = 'stacked', 
                                denied_action = null, )
                            ], 
                        configure_flow = '', 
                        friendly_name = '', 
                        use_global_settings = True, 
                        host = '', 
                        port = -2147483648, 
                        username = '', 
                        password = '', 
                        use_tls = True, 
                        use_ssl = True, 
                        timeout = -2147483648, 
                        from_address = '', 
                        subject = '', 
                        token_expiry = '', 
                        template = '', )
                    ],
                autocomplete = {
                    'key' : null
                    },
        )
        """

    def testPaginatedAuthenticatorEmailStageList(self):
        """Test PaginatedAuthenticatorEmailStageList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
